package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletUserLogin;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 用户登录记录Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-05
 */
public interface PlayletUserLoginMapper extends BaseMapper<PlayletUserLogin>
{
    /**
     * 查询用户登录记录
     *
     * @param id 用户登录记录主键
     * @return 用户登录记录
     */
    public PlayletUserLogin selectPlayletUserLoginById(Long id);

    /**
     * 查询用户登录记录列表
     *
     * @param playletUserLogin 用户登录记录
     * @return 用户登录记录集合
     */
    public List<PlayletUserLogin> selectPlayletUserLoginList(PlayletUserLogin playletUserLogin);

    /**
     * 新增用户登录记录
     *
     * @param playletUserLogin 用户登录记录
     * @return 结果
     */
    public int insertPlayletUserLogin(PlayletUserLogin playletUserLogin);

    /**
     * 修改用户登录记录
     *
     * @param playletUserLogin 用户登录记录
     * @return 结果
     */
    public int updatePlayletUserLogin(PlayletUserLogin playletUserLogin);

    /**
     * 删除用户登录记录
     *
     * @param id 用户登录记录主键
     * @return 结果
     */
    public int deletePlayletUserLoginById(Long id);

    /**
     * 批量删除用户登录记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletUserLoginByIds(String[] ids);
}
